// Template.h: CTemplate NX̃C^[tFCX
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_TEMPLATE_H__299BF777_A75B_4EEF_9C11_32651414E859__INCLUDED_)
#define AFX_TEMPLATE_H__299BF777_A75B_4EEF_9C11_32651414E859__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "MimeDecode.h"

class CTemplate  
{
public:
// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
	void SetAddress(CString address);
	void SetSignature(CString signature);
// end
	CString GetString(CMimeDecode *md, CString tmpl);
// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
//	void SetCurrentBody(CString body);
	void SetBody(CString body);
// end
	CTemplate();
	virtual ~CTemplate();

protected:
	CString m_body;
// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
	CString m_address;
	CString m_signature;
// end
};

#endif // !defined(AFX_TEMPLATE_H__299BF777_A75B_4EEF_9C11_32651414E859__INCLUDED_)
